==> haskell-test-framework-hunit-0.3.0.2-45-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-test-framework-hunit.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: test-framework-hunit
version: 0.3.0.2
id: test-framework-hunit-0.3.0.2-FNpYTKNqZkT79TB7SPpOf3
key: test-framework-hunit-0.3.0.2-FNpYTKNqZkT79TB7SPpOf3
license: BSD-3-Clause
maintainer: Haskell Libraries <libraries@haskell.org>
author: Max Bolingbroke <batterseapower@hotmail.com>
homepage: https://batterseapower.github.io/test-framework/
synopsis: HUnit support for the test-framework package.
description:
    HUnit support for the test-framework package.
category: Testing
abi: f139a68abbe5ec62a0bc9466da6986e0
exposed: True
exposed-modules:
    Test.Framework.Providers.HUnit
import-dirs: /usr/lib/ghc-8.6.5/site-local/test-framework-hunit-0.3.0.2
library-dirs: /usr/lib/ghc-8.6.5/site-local/test-framework-hunit-0.3.0.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/test-framework-hunit-0.3.0.2
hs-libraries: HStest-framework-hunit-0.3.0.2-FNpYTKNqZkT79TB7SPpOf3
depends:
    HUnit-1.6.0.0-Kc3RXVOuMSQ9Y4PmNrdWEj base-4.12.0.0
    extensible-exceptions-0.1.1.4-KI0dG6kQM84KnSzvR2Yb0
    test-framework-0.8.2.0-Kw9JrwBTWdAJO9hYgX4lSm
haddock-interfaces: /usr/share/doc/haskell-test-framework-hunit/html/test-framework-hunit.haddock
haddock-html: /usr/share/doc/haskell-test-framework-hunit/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-test-framework-hunit-0.3.0.2-46-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-test-framework-hunit.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: test-framework-hunit
version: 0.3.0.2
id: test-framework-hunit-0.3.0.2-AUvDMODuuEQ5DvQ81J8cMW
key: test-framework-hunit-0.3.0.2-AUvDMODuuEQ5DvQ81J8cMW
license: BSD-3-Clause
maintainer: Haskell Libraries <libraries@haskell.org>
author: Max Bolingbroke <batterseapower@hotmail.com>
homepage: https://batterseapower.github.io/test-framework/
synopsis: HUnit support for the test-framework package.
description:
    HUnit support for the test-framework package.
category: Testing
abi: 29956f6b121127f67f6c6f9664edb693
exposed: True
exposed-modules:
    Test.Framework.Providers.HUnit
import-dirs: /usr/lib/ghc-8.6.5/site-local/test-framework-hunit-0.3.0.2
library-dirs: /usr/lib/ghc-8.6.5/site-local/test-framework-hunit-0.3.0.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/test-framework-hunit-0.3.0.2
hs-libraries: HStest-framework-hunit-0.3.0.2-AUvDMODuuEQ5DvQ81J8cMW
depends:
    HUnit-1.6.0.0-Kc3RXVOuMSQ9Y4PmNrdWEj base-4.12.0.0
    extensible-exceptions-0.1.1.4-KI0dG6kQM84KnSzvR2Yb0
    test-framework-0.8.2.0-2dhLXXIyuWjLumyCVFTYFd
haddock-interfaces: /usr/share/doc/haskell-test-framework-hunit/html/test-framework-hunit.haddock
haddock-html: /usr/share/doc/haskell-test-framework-hunit/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
